'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _cssfile = require('./cssfile');

var _cssfile2 = _interopRequireDefault(_cssfile);

var _htmlfile = require('./htmlfile');

var _htmlfile2 = _interopRequireDefault(_htmlfile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Search file paths.
 * @private
 * @param {String} dir - a file path
 * @param {Array} result - found files after run
 */
function walk(dir, result) {
  var stat = _fs2.default.statSync(dir);

  if (stat.isFile()) {
    result.push(dir);
  } else if (stat.isDirectory()) {
    _fs2.default.readdirSync(dir).forEach(function (item) {
      return walk(_path2.default.join(dir, item), result);
    });
  }
}

/**
 * Return files.
 * @private
 * @param {String} dir - a file path
 * @param {Object} options - specify a extention
 * @return {Array} -
 */
function find(dir, options) {
  var result = [];
  walk(dir, result);

  if (options.ext) {
    return result.filter(function (f) {
      return _path2.default.extname(f) === '.' + options.ext;
    });
  }

  return result;
}

/**
 * Return css files.
 * @public
 * @param {String} dir - a file path
 * @return {Array} -
 */
function findCssFiles(dir) {
  var files = find(dir, { ext: 'css' });
  return files.map(function (f) {
    return new _cssfile2.default(f);
  });
}

/**
 * Return html files.
 * @public
 * @param {String} dir - a file path
 * @return {Array} -
 */
function findHtmlFiles(dir) {
  var files = find(dir, { ext: 'html' });
  return files.map(function (f) {
    return new _htmlfile2.default(f);
  });
}

exports.default = { findCssFiles: findCssFiles, findHtmlFiles: findHtmlFiles };
//# sourceMappingURL=../maps/explorer.js.map
